@@ -492,6 +492,8 @@ gboolean signal_button_press(GtkWidget *widget,
 			LINEBUF *p;
 			GdkPoint cursor;
 
+			if (event->button!=1)
+				return FALSE;
 			/* ֥륯åȤñ򤹤 */
 			if (ptw->select.x>=0)
 				break;
@@ -994,7 +996,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		break;
 	default:
 		loop:
-		if (event->string!=NULL && (guchar)event->string[0]>=' ') {
+		if (event->string!=NULL
+				&& ((guchar)event->string[0]>=' ' || event->string[0]=='\t')) {
 			DOING *d;
 			GdkPoint select;
 
